# TODO List

Not in any specific order :

- Improve error-checking and recovery
- Add command line options to modify configuration, and a config file. Any
  options on command line to have precedence over settings specified in the
  configuration file.
- re-add logging.
- Add command line options for quiet and verbose, with same options in the
  config file.
- Option to save log file for each run.
- Add testing!
